@@ -23,7 +23,7 @@ ALL_PRESETS = [
 ]
 
 
-def biogas_presets(pn_max_kw, **kwargs):
+def biogas_preset(pn_max_kw, **kwargs):
     """Return the parameter configuration for a biogas model from the
     pysimmods package.
 
