@@ -10,6 +10,7 @@ def pv_preset(
     cos_phi=0.9,
     q_control="prioritize_p",
     inverter_mode="inductive",
+    is_static_t_module=False,
 ):
     """Return a preset configuration for a PV plant.
 
@@ -39,7 +40,11 @@ def pv_preset(
 
     """
     params = {
-        "pv": {"a_m2": p_peak_kw / eta, "eta_percent": eta * 100},
+        "pv": {
+            "a_m2": p_peak_kw / eta,
+            "eta_percent": eta * 100,
+            "is_static_t_module": is_static_t_module,
+        },
         "inverter": {
             "sn_kva": p_peak_kw / cos_phi,
             "q_control": q_control,
