@@ -219,9 +219,7 @@ class FlexibilitySimulator(PysimmodsSimulator):
             The next step this simulator wants to be stepped.
 
         """
-        if self.key_value_logs:
-            LOG.info(inputs)  # TODO
-        else:
+        if not self.key_value_logs:
             LOG.debug("At step %d: Received inputs: %s.", time, inputs)
 
         self._set_default_inputs()
