@@ -45,7 +45,7 @@ class PysimmodsModule(UpgradeModule):
                 "Photovoltaic",
                 "sgen",
                 ["bh_w_per_m2", "dh_w_per_m2", "t_air_deg_celsius"],
-                ["p_mw", "q_mvar"],
+                ["p_mw", "q_mvar", "t_module_deg_celsius"],
             ),
             "HVAC": (
                 "HVAC",
@@ -87,6 +87,7 @@ class PysimmodsModule(UpgradeModule):
             "forecast_horizon_hours",
             self.scenario.base.forecast_horizon_hours,
         )
+        module_params.setdefault("pv_is_static_t_module", False)
         module_params.setdefault("provide_flexibilities", False)
         module_params.setdefault(
             "flexibility_horizon_hours",
@@ -117,6 +118,9 @@ class PysimmodsModule(UpgradeModule):
         self.sim_params.setdefault(
             "inverter_mode", module_params["inverter_mode"]
         )
+        self.sim_params.setdefault(
+            "pv_is_static_t_module", module_params["pv_is_static_t_module"]
+        )
         self.sim_params.setdefault(
             "forecast_horizon_hours",
             module_params["forecast_horizon_hours"],
@@ -372,7 +376,9 @@ class PysimmodsModule(UpgradeModule):
             q_control=self.sim_params["q_control"],
             cos_phi=self.sim_params["cos_phi"],
             inverter_mode=self.sim_params["inverter_mode"],
+            is_static_t_module=self.sim_params["pv_is_static_t_module"],
         )
+
         self.sim_params.setdefault(model_key, dict())
         self.sim_params[model_key].setdefault("params", mod_params)
         self.sim_params[model_key].setdefault("inits", mod_inits)
@@ -549,7 +555,9 @@ def create_actuator(
 ):
     return {
         "actuator_id": f"{full_id}.{attr}",
-        "action_space": (f"Box(low={vmin}, high={vmax}, dtype={dtype})"),
+        "action_space": (
+            f"Box(low={vmin}, high={vmax}, shape=(1,), dtype={dtype})"
+        ),
     }
 
 
@@ -562,7 +570,9 @@ def create_sensor(
 ):
     return {
         "sensor_id": f"{full_id}.{attr}",
-        "observation_space": (f"Box(low={vmin}, high={vmax}, dtype={dtype})"),
+        "observation_space": (
+            f"Box(low={vmin}, high={vmax}, shape=(1,), dtype={dtype})"
+        ),
     }
 
 
