@@ -7,6 +7,7 @@ import logging
 import pprint
 from datetime import datetime, timedelta, timezone
 from typing import Any, Dict
+import warnings
 
 import mosaik_api
 import numpy as np
@@ -247,6 +248,10 @@ class PysimmodsSimulator(mosaik_api.Simulator):
 
         # Set the inputs
         if attr == "set_percent":
+            warnings.warn(
+                "Using set_percent is deprecated and will be removed with pysimmods>=0.9.0",
+                UserWarning,
+            )
             self._set_percent_power(eid, attr_sum)
         elif attr == "p_set_kw":
             self.models[eid].set_p_kw(attr_sum)
